@@ -11,7 +11,7 @@ import logging
 import pathlib
 from types import FrameType
 import typing
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Callable
 
 import attrs
 from frozendict import deepfreeze, frozendict
@@ -305,6 +305,7 @@ class EntityMetadata:
     cluster_type: ClusterType = attrs.field(default=ClusterType.Server)
     initially_disabled: bool = attrs.field(default=False)
     attribute_initialized_from_cache: bool = attrs.field(default=True)
+    unique_id_suffix: str | None = attrs.field(default=None)
     translation_key: str | None = attrs.field(default=None)
     fallback_name: str = attrs.field(validator=attrs.validators.instance_of(str))
 
@@ -342,6 +343,7 @@ class ZCLSensorMetadata(EntityMetadata):
     """Metadata for exposed ZCL attribute based sensor entity."""
 
     attribute_name: str | None = attrs.field(default=None)
+    attribute_converter: typing.Callable[[Any], Any] | None = attrs.field(default=None)
     reporting_config: ReportingConfig | None = attrs.field(default=None)
     divisor: int | None = attrs.field(default=None)
     multiplier: int | None = attrs.field(default=None)
@@ -382,6 +384,7 @@ class BinarySensorMetadata(EntityMetadata):
     """Metadata for exposed binary sensor entity."""
 
     attribute_name: str = attrs.field()
+    attribute_converter: typing.Callable[[Any], Any] | None = attrs.field(default=None)
     reporting_config: ReportingConfig | None = attrs.field(default=None)
     device_class: BinarySensorDeviceClass | None = attrs.field(default=None)
 
@@ -435,6 +438,16 @@ class DeviceAlertMetadata:
     message: str = attrs.field()
 
 
+@attrs.define(frozen=True, kw_only=True, repr=True)
+class PreventDefaultEntityCreationMetadata:
+    """Metadata to prevent the default creation of an entity."""
+
+    endpoint_id: int | None = attrs.field()
+    cluster_id: int | None = attrs.field()
+    unique_id_suffix: str | None = attrs.field()
+    function: Callable[Any, bool] | None = attrs.field()
+
+
 @attrs.define(frozen=True, kw_only=True, repr=True)
 class QuirksV2RegistryEntry:
     """Quirks V2 registry entry."""
@@ -446,6 +459,9 @@ class QuirksV2RegistryEntry:
     )
     friendly_name: FriendlyNameMetadata | None = attrs.field(default=None)
     device_alerts: tuple[DeviceAlertMetadata] = attrs.field(factory=tuple)
+    disabled_default_entities: tuple[PreventDefaultEntityCreationMetadata] = (
+        attrs.field(factory=tuple)
+    )
     filters: tuple[FilterType] = attrs.field(factory=tuple)
     custom_device_class: type[CustomDeviceV2] | None = attrs.field(default=None)
     device_node_descriptor: NodeDescriptor | None = attrs.field(default=None)
@@ -507,6 +523,7 @@ class QuirkBuilder:
         self.manufacturer_model_metadata: list[ManufacturerModelMetadata] = []
         self.friendly_name_metadata: FriendlyNameMetadata | None = None
         self.device_alerts: list[DeviceAlertMetadata] = []
+        self.disabled_default_entities: list[PreventDefaultEntityCreationMetadata] = []
         self.filters: list[FilterType] = []
         self.custom_device_class: type[CustomDeviceV2] | None = None
         self.device_node_descriptor: NodeDescriptor | None = None
@@ -752,6 +769,7 @@ class QuirkBuilder:
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
         reporting_config: ReportingConfig | None = None,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -769,6 +787,7 @@ class QuirkBuilder:
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
                 reporting_config=reporting_config,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 enum=enum_class,
@@ -791,7 +810,9 @@ class QuirkBuilder:
         unit: str | None = None,
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
+        attribute_converter: typing.Callable[[Any], Any] | None = None,
         reporting_config: ReportingConfig | None = None,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -809,9 +830,11 @@ class QuirkBuilder:
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
                 reporting_config=reporting_config,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 attribute_name=attribute_name,
+                attribute_converter=attribute_converter,
                 divisor=divisor,
                 multiplier=multiplier,
                 unit=unit,
@@ -836,6 +859,7 @@ class QuirkBuilder:
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
         reporting_config: ReportingConfig | None = None,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -853,6 +877,7 @@ class QuirkBuilder:
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
                 reporting_config=reporting_config,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 attribute_name=attribute_name,
@@ -881,6 +906,7 @@ class QuirkBuilder:
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
         reporting_config: ReportingConfig | None = None,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -898,6 +924,7 @@ class QuirkBuilder:
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
                 reporting_config=reporting_config,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 attribute_name=attribute_name,
@@ -922,7 +949,9 @@ class QuirkBuilder:
         device_class: BinarySensorDeviceClass | None = None,
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
+        attribute_converter: typing.Callable[[Any], Any] | None = None,
         reporting_config: ReportingConfig | None = None,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -940,9 +969,11 @@ class QuirkBuilder:
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
                 reporting_config=reporting_config,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 attribute_name=attribute_name,
+                attribute_converter=attribute_converter,
                 device_class=device_class,
             )
         )
@@ -958,6 +989,7 @@ class QuirkBuilder:
         entity_type: EntityType = EntityType.CONFIG,
         initially_disabled: bool = False,
         attribute_initialized_from_cache: bool = True,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -975,6 +1007,7 @@ class QuirkBuilder:
                 entity_type=entity_type,
                 initially_disabled=initially_disabled,
                 attribute_initialized_from_cache=attribute_initialized_from_cache,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 attribute_name=attribute_name,
@@ -993,6 +1026,7 @@ class QuirkBuilder:
         endpoint_id: int = 1,
         entity_type: EntityType = EntityType.CONFIG,
         initially_disabled: bool = False,
+        unique_id_suffix: str | None = None,
         translation_key: str | None = None,
         fallback_name: str | None = None,
     ) -> QuirkBuilder:
@@ -1009,6 +1043,7 @@ class QuirkBuilder:
                 entity_platform=EntityPlatform.BUTTON,
                 entity_type=entity_type,
                 initially_disabled=initially_disabled,
+                unique_id_suffix=unique_id_suffix,
                 translation_key=translation_key,
                 fallback_name=fallback_name,
                 command_name=command_name,
@@ -1037,6 +1072,25 @@ class QuirkBuilder:
         self.device_alerts.append(DeviceAlertMetadata(level=level, message=message))
         return self
 
+    def prevent_default_entity_creation(
+        self,
+        *,
+        endpoint_id: int | None = None,
+        cluster_id: int | None = None,
+        unique_id_suffix: str | None = None,
+        function: Callable[Any, bool] | None = None,
+    ) -> QuirkBuilder:
+        """Do not create default entities."""
+        self.disabled_default_entities.append(
+            PreventDefaultEntityCreationMetadata(
+                endpoint_id=endpoint_id,
+                cluster_id=cluster_id,
+                unique_id_suffix=unique_id_suffix,
+                function=function,
+            ),
+        )
+        return self
+
     def add_to_registry(self) -> QuirksV2RegistryEntry:
         """Build the quirks v2 registry entry."""
         if not self.manufacturer_model_metadata:
@@ -1047,6 +1101,7 @@ class QuirkBuilder:
             manufacturer_model_metadata=tuple(self.manufacturer_model_metadata),
             friendly_name=self.friendly_name_metadata,
             device_alerts=tuple(self.device_alerts),
+            disabled_default_entities=tuple(self.disabled_default_entities),
             quirk_file=self.quirk_file,
             quirk_file_line=self.quirk_file_line,
             filters=tuple(self.filters),
