@@ -173,14 +173,17 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin):
             for name in dir(defs):
                 definition = getattr(defs, name)
 
-                if (
-                    isinstance(
-                        definition,
-                        (foundation.ZCLCommandDef, foundation.ZCLAttributeDef),
-                    )
-                    and definition.name is None
+                if isinstance(
+                    definition,
+                    (foundation.ZCLCommandDef, foundation.ZCLAttributeDef),
                 ):
-                    object.__setattr__(definition, "name", name)
+                    if definition.name is None:
+                        object.__setattr__(definition, "name", name)
+                    elif definition.name != name:
+                        raise TypeError(
+                            f"Definition name {definition.name!r} does not match"
+                            f" attribute name {name!r}"
+                        )
 
         # Compile the schemas
         for defs in (cls.ServerCommandDefs, cls.ClientCommandDefs):
@@ -679,11 +682,11 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin):
         args = self._write_attr_records(attributes)
         return self._write_attributes_undivided(args, manufacturer=manufacturer)
 
-    def bind(self):
-        return self._endpoint.device.zdo.bind(cluster=self)
+    async def bind(self):
+        return await self._endpoint.device.zdo.bind(cluster=self)
 
-    def unbind(self):
-        return self._endpoint.device.zdo.unbind(cluster=self)
+    async def unbind(self):
+        return await self._endpoint.device.zdo.unbind(cluster=self)
 
     def _attr_reporting_rec(
         self,
